==> openshift-model-6.7.1-sources.jar: io/fabric8/openshift/api/model/BuildPostCommitSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BuildPostCommitSpecBuilder extends BuildPostCommitSpecFluentImpl<BuildPostCommitSpecBuilder> implements VisitableBuilder<BuildPostCommitSpec,BuildPostCommitSpecBuilder>{
  public BuildPostCommitSpecBuilder() {
    this(false);
  }
  public BuildPostCommitSpecBuilder(Boolean validationEnabled) {
    this(new BuildPostCommitSpec(), validationEnabled);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BuildPostCommitSpec(), validationEnabled);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpecFluent<?> fluent,BuildPostCommitSpec instance) {
    this(fluent, instance, false);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpecFluent<?> fluent,BuildPostCommitSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withArgs(instance.getArgs());
      fluent.withCommand(instance.getCommand());
      fluent.withScript(instance.getScript());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpec instance) {
    this(instance,false);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withArgs(instance.getArgs());
      this.withCommand(instance.getCommand());
      this.withScript(instance.getScript());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  BuildPostCommitSpecFluent<?> fluent;
  Boolean validationEnabled;
  public BuildPostCommitSpec build() {
    BuildPostCommitSpec buildable = new BuildPostCommitSpec(fluent.getArgs(),fluent.getCommand(),fluent.getScript());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/BuildPostCommitSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BuildPostCommitSpecBuilder extends BuildPostCommitSpecFluent<BuildPostCommitSpecBuilder> implements VisitableBuilder<BuildPostCommitSpec,BuildPostCommitSpecBuilder>{
  public BuildPostCommitSpecBuilder() {
    this(false);
  }
  public BuildPostCommitSpecBuilder(Boolean validationEnabled) {
    this(new BuildPostCommitSpec(), validationEnabled);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BuildPostCommitSpec(), validationEnabled);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpecFluent<?> fluent,BuildPostCommitSpec instance) {
    this(fluent, instance, false);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpecFluent<?> fluent,BuildPostCommitSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new BuildPostCommitSpec());

    if (instance != null) {
      fluent.withArgs(instance.getArgs());
      fluent.withCommand(instance.getCommand());
      fluent.withScript(instance.getScript());
      fluent.withArgs(instance.getArgs());
      fluent.withCommand(instance.getCommand());
      fluent.withScript(instance.getScript());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpec instance) {
    this(instance,false);
  }
  public BuildPostCommitSpecBuilder(BuildPostCommitSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new BuildPostCommitSpec());

    if (instance != null) {
      this.withArgs(instance.getArgs());
      this.withCommand(instance.getCommand());
      this.withScript(instance.getScript());
      this.withArgs(instance.getArgs());
      this.withCommand(instance.getCommand());
      this.withScript(instance.getScript());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  BuildPostCommitSpecFluent<?> fluent;
  Boolean validationEnabled;
  public BuildPostCommitSpec build() {
    BuildPostCommitSpec buildable = new BuildPostCommitSpec(fluent.getArgs(),fluent.getCommand(),fluent.getScript());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
